@@ -151,7 +151,7 @@ CindexBootstrapCrossValidation <- function(object,
           NA
         else{
           if (predictHandlerFun %in% c("predictEventProb","predictLifeYearsLost")){
-            Step.b.CindexResult <- .C("ccr",cindex=double(NT),concA=double(NT),pairsA=double(NT),concB=double(NT),pairsB=double(NT),as.integer(tindex.b),as.double(Y.b),as.integer(status[vindex.b]),as.integer(event[vindex.b]),as.double(eval.times),as.double(ipcw.b.i),as.double(ipcw.b.j),as.double(pred.b),as.integer(sum(vindex.b)),as.integer(NT),as.integer(tiedPredictionsIn),as.integer(tiedOutcomeIn),as.integer(tiedMatchIn),as.integer(!is.null(dim(ipcw.b.j))),NAOK=TRUE,package="pec")
+            Step.b.CindexResult <- .C("ccr",cindex=double(NT),concA=double(NT),pairsA=double(NT),concB=double(NT),pairsB=double(NT),as.integer(tindex.b),as.double(Y.b),as.integer(status[vindex.b]),as.integer(event[vindex.b]),as.double(eval.times),as.double(ipcw.b.i),as.double(ipcw.b.j),as.double(pred.b),as.integer(sum(vindex.b)),as.integer(NT),as.integer(tiedPredictionsIn),as.integer(tiedOutcomeIn),as.integer(tiedMatchIn),as.integer(!is.null(dim(ipcw.b.j))),NAOK=TRUE,PACKAGE="pec")
             Step.b.Cindex <- Step.b.CindexResult$cindex
             Step.b.PairsA <- Step.b.CindexResult$pairsA
             Step.b.ConcordantA <- Step.b.CindexResult$concA
@@ -160,7 +160,7 @@ CindexBootstrapCrossValidation <- function(object,
             list(Cindex.b=Step.b.Cindex,Pairs.b=list(A=Step.b.PairsA,B=Step.b.PairsB),Concordant.b=list(A=Step.b.ConcordantA,B=Step.b.ConcordantB))
           }
           else{
-            cindexOut <- .C("cindex",
+            cindexOut <- .C("cindexSRC",
                             cindex=double(NT),
                             conc=double(NT),
                             pairs=double(NT),
@@ -178,7 +178,7 @@ CindexBootstrapCrossValidation <- function(object,
                             as.integer(tiedMatchIn),
                             as.integer(!is.null(dim(ipcw.b.j))),
                             NAOK=TRUE,
-                            package="pec")            
+                            PACKAGE="pec")            
             Cindex.b <- cindexOut$cindex
             Pairs.b <- cindexOut$pairs 
             Concordant.b <- cindexOut$conc
