@@ -104,13 +104,16 @@ predictEventProb.FGR <- function(object,newdata,times,cause,...){
 
 ##' @export
 predictEventProb.riskRegression <- function(object,newdata,times,cause,...){
-  if (missing(times))stop("Argument times is missing")
-  temp <- predict(object,newdata=newdata,times=times)
-  pos <- prodlim::sindex(jump.times=temp$time,eval.times=times)
-  p <- cbind(0,t(temp$risk))[,pos+1,drop=FALSE]
-  if (NROW(p) != NROW(newdata) || NCOL(p) != length(times))
-            stop(paste("\nPrediction matrix has wrong dimension:\nRequested newdata x times: ",NROW(newdata)," x ",length(times),"\nProvided prediction matrix: ",NROW(p)," x ",NCOL(p),"\n\n",sep=""))
-  p
+    if (missing(times))stop("Argument times is missing")
+    temp <- predict(object,newdata=newdata,times=times)
+    pos <- prodlim::sindex(jump.times=temp$time,eval.times=times)
+    ## if (NROW(newdata)==1)
+        p <- cbind(0,temp$risk)[,pos+1,drop=FALSE]
+    ## else
+        ## p <- cbind(0,t(temp$risk))[,pos+1,drop=FALSE]
+    if (NROW(p) != NROW(newdata) || NCOL(p) != length(times))
+        stop(paste("\nPrediction matrix has wrong dimension:\nRequested newdata x times: ",NROW(newdata)," x ",length(times),"\nProvided prediction matrix: ",NROW(p)," x ",NCOL(p),"\n\n",sep=""))
+    p
 }
 
 ##' @export 
@@ -159,11 +162,11 @@ predictEventProb.CauseSpecificCox <- function (object, newdata, times, cause, ..
     if (survtype=="hazard"){
         ## browser()
         cumHazOther <- lapply(causes[-match(cause,causes)],function(c){
-                                        trycumhaz <- try(cumHaz.c <- -log(predictSurvProb(object$models[[paste("Cause",c)]],times=eTimes,newdata=newdata)),silent=FALSE)
-                                        if (inherits(trycumhaz,"try-error")==TRUE)
-                                            stop("Prediction of cause-specific Cox model failed")
-                                        cumHaz.c
-                                    })
+            trycumhaz <- try(cumHaz.c <- -log(predictSurvProb(object$models[[paste("Cause",c)]],times=eTimes,newdata=newdata)),silent=FALSE)
+            if (inherits(trycumhaz,"try-error")==TRUE)
+                stop("Prediction of cause-specific Cox model failed")
+            cumHaz.c
+        })
         lagsurv <- exp(-cumHaz1 - Reduce("+",cumHazOther))
         cuminc1 <- t(apply(lagsurv*Haz1,1,cumsum))
     }
